require 'jade-rails'
require 'test/unit'

class JadeTest < Test::Unit::TestCase
  JADE_TEMPLATE_FUNCTION_PATTERN = /^function\s+template\s*\(locals\)\s*\{.*\}$/m

  def test_compile
    template = File.read(File.expand_path('../assets/javascripts/jade/sample_template.jade', __FILE__))
    result = Jade.compile(template)
    assert_match(JADE_TEMPLATE_FUNCTION_PATTERN, result)
    assert_no_match(/^\s*<!DOCTYPE html>/, result)
  end

  def test_compile_with_io
    io = StringIO.new('string of jade')
    assert_equal Jade.compile('string of jade'), Jade.compile(io)
  end

  def test_compilation_error
    assert_raise Jade::CompileError do
      Jade.compile <<-JADE
        else
          .foo
      JADE
    end
  end

  def test_includes
    file = File.expand_path('../assets/javascripts/jade/includes/index.jade', __FILE__)
    template = File.read(file)
    result = Jade.compile(template, filename: file)
    assert_match(JADE_TEMPLATE_FUNCTION_PATTERN, result)
    assert_no_match(/^\s*<!DOCTYPE html>/, result)
  end

  def test_extends
    file = File.expand_path('../assets/javascripts/jade/extends/layout.jade', __FILE__)
    template = File.read(file)
    result = Jade.compile(template, filename: file)
    assert_match(JADE_TEMPLATE_FUNCTION_PATTERN, result)
    assert_no_match(/^\s*<!DOCTYPE html>/, result)
  end
end
